#
# spec file for package python-hyper
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-hyper
Version:        0.7.0+git88.18b629b
Release:        lp152.3.1
Summary:        HTTP/2 Client for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Lukasa/hyper
Source0:        hyper-%{version}.tar.xz
Patch0:         fix-dependencies.patch
Patch1:         fix-test.patch
Patch2:         pr-402-h2-settings-fix.patch
Patch3:         tests-mark-rpmfail_getaddrinfo.patch
Patch4:         fix-j1-tests.patch
Patch5:         http20.patch
BuildRequires:  %{python_module brotlipy >= 0.7.0}
BuildRequires:  %{python_module h2 > 2.5.0}
BuildRequires:  %{python_module hyperframe >= 3.2}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest >= 3.0}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module rfc3986 >= 1.1.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module virtualenv >= 14.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-brotlipy >= 0.7.0
Requires:       python-h2 > 2.5.0
Requires:       python-hyperframe >= 3.2
Requires:       python-rfc3986 >= 1.1.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if %{with python2}
BuildRequires:  python-enum34 >= 1.0.4
BuildRequires:  python-futures
%endif
%ifpython2
Requires:       python-enum34
%endif
%python_subpackages

%description
hyper supports the final draft of the HTTP/2 specification: additionally,
it provides support for drafts 14, 15, and 16 of the HTTP/2 specification.
It also supports the final draft of the HPACK specification.

hyper is intended to be a drop-in replacement for http.client, with a
similar API. However, hyper intentionally does not name its classes the
same way http.client does. This is because most servers do not support
HTTP/2 at this time: I don't want you accidentally using hyper when you
wanted http.client.

%prep
%setup -q -n hyper-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/hyper
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_HTTPConnection_with_custom_context - TLS 1.3 does not support h2
# test_useful_error_with_no_protocol test_goaway_frame_PROTOCOL_ERROR test_goaway_frame_HTTP_1_1_REQUIRED test_goaway_frame_invalid_error_code - httplib update changed error messages reported
%python_exec setup.py pytest --addopts="test/ -k 'not (rpmfail_getaddrinfo or test_HTTPConnection_with_custom_context or test_useful_error_with_no_protocol or test_goaway_frame_PROTOCOL_ERROR or test_goaway_frame_HTTP_1_1_REQUIRED or test_goaway_frame_invalid_error_code)'"

%post
%python_install_alternative hyper

%postun
%python_uninstall_alternative hyper

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/hyper
%{python_sitelib}/hyper*

%changelog
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix http20 behaviour:
  * http20.patch
- Skip error reporting tests as they do not match httplib update
* Fri Jun 21 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add fix-j1-tests.patch to make build work on 1-core-VM
* Tue May 28 2019 tchvatal@suse.com
- Skip one test that fails on TLS-1.3 because it is no longer
  supported openssl behaviour being tested
* Thu Mar 28 2019 John Vandenberg <jayvdb@gmail.com>
- Add pr-402-http20-enable-push-fix.patch from upstream
  to fix http20 connection initialisation
- Improve fix-dependencies.patch removing upper constraints
- Merge hyper executable into main package
- Remove bcond test
- Simplify test invocation
- Add missing test dependency 'futures' on Python 2.7
* Wed Mar 27 2019 jayvdb@gmail.com
- Update to version 0.7.0+git88.18b629b:
  * Add a fix to make it possible to add window_manager to HTTP20Adapter.
  * Add support for brotli compression
  * Fix crash on getting unsupported content-encoding
  * fix HTTP/1.1 response body length
  * fix HTTP/1.1 response body length
  * fix some error
  * Add test function for length of the HTTP/1.1 response-body.
  * fix HEAD request body length
  * fix test_release (http2bin to nghttp2.org/httpbin)
* Mon Apr 16 2018 Martijn Goedhart <goedhart.martijn@gmail.com>
- Initial spec for version 0.7.0+git88.18b629b, adding
  fix-test.patch to de-vendor the tests and
  fix-dependencies.patch to unpin dependencies
